$\texttt{tropygal}$ is a pure-python package for entropy estimates in
the context of galacitc dynamics, but can be used in other contexts
too. It also provides functions for analytical distribution functions
and density of states for models that have analytical
expressions.

Read the docs [here](https://tropygal.readthedocs.io/en/latest/).

Detailed expressions and numerical tests can be found in [Beraldo e
Silva et al
2025](https://ui.adsabs.harvard.edu/abs/2024arXiv240707947B/abstract). Please,
cite this paper if you use $\texttt{tropygal}$.

## Acknowledgements

Development of **tropygal** was supported by the following research grants

- NASA ATP awards 80NSSC20K0509 and 80NSSC24K0938  
- U.S. NSF AAG grant AST-2009122  
- STFC Ernest Rutherford fellowship (ST/X004066/1)  
- JSPS KAKENHI Grant Numbers JP24K07101, JP21K13965, and JP21H00053  
- CNPq (309723/2020-5)  
- Heising Simons Foundation grant \# 2022-3927

Funding agencies:

- **NASA ATP** - NASA Astrophysical Theory Program (US)  
- **NSF** - National Science Foundation (US)  
- **STFC** - Science and Technology Facilities Council (UK)  
- **JSPS** - Japan Society for the Promotion of Science (Japan)  
- **CNPq** – Conselho Nacional de Desenvolvimento Científico e Tecnológico (Brasil)  
- Heising Simons Foundation (US)
